<?php

namespace App\Form;

use App\Dto\FiltersDTO;
use App\Entity\User;
use App\Repository\UserRepository;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\NumberType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class FiltersType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('note', NumberType::class, [
                'required'  => false,
                'label'       => "Note au dessus de",
                'attr'      => [
                    'data-clear-value' => '0',
                    'class' => "rating",
                    'data-min-threshold' => '0',
                    'data-min'  => '0',
                    'data-max'  => '5',
                    'data-step' => 1,
                    'data-show-clear'   => "true",
                    'data-show-caption' => "false",
                    'data-size'         => "sm",
                    'data-theme'          => "krajee-fa"
                ],
            ])
            ->add('limit', ChoiceType::class, [
                'choices' => [
                    '10' => 10,
                    '25' => 25,
                    '50' => 50,
                    '100' => 100
                ]
            ])
            ->add('userName', EntityType::class, [
                'required' => false,
                'class' => User::class,
                'choice_label' => 'username',
                'choice_value' => function(?User $user): string {
                        return $user ? $user->getUsername() : '';
                },
                'query_builder' => function (UserRepository $er): QueryBuilder {
                    return $er->createQueryBuilder('u')
                        ->orderBy('u.username', 'ASC');
                }
            ])
            ->add('sortBy', ChoiceType::class, [
                'choices' => [
                    'Date de soumission' => 'dateSubmited',
                    'Titre' => 'titre',
                    'Année' => 'annee',
                    'Note' => 'note'
                ]
            ])
            ->add('sortOrder', ChoiceType::class, [
                'choices' => [
                    'ASC' => 'ASC',
                    'DESC' => 'DESC'
                ]
            ])
        ;
    }

    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class'    => FiltersDTO::class,
            'method'        => 'GET',
            'csrf_protection' => false,
        ]);
    }
}
